<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AuthDialog</name>
    <message>
        <location filename="auth_dialog.ui" line="32"/>
        <source>Get Auth code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="auth_dialog.ui" line="78"/>
        <source>1. Click the following button to open permission page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="auth_dialog.ui" line="91"/>
        <source>2. Allow the access in the page, and copy&amp;paste the auth code in the box below</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="auth_dialog.ui" line="123"/>
        <source>Open Browser...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="config_dialog.ui" line="32"/>
        <source>Mozc settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="92"/>
        <source>Input mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="172"/>
        <source>Keymap style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="185"/>
        <location filename="config_dialog.ui" line="192"/>
        <location filename="config_dialog.ui" line="1230"/>
        <source>Customize...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="218"/>
        <source>Basics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="949"/>
        <source>Privacy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="250"/>
        <source>Keymap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="199"/>
        <source>Romaji table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="272"/>
        <source>Dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="294"/>
        <source>Adjust conversion based on previous input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="364"/>
        <source>Edit user dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="458"/>
        <source>Personalization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="522"/>
        <source>User dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="601"/>
        <source>Input Assistance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="633"/>
        <source>Fullwidth/Halfwidth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="672"/>
        <source>Shift key mode switch</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="config_dialog.ui" line="695"/>
        <source>、</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="config_dialog.ui" line="728"/>
        <source>。</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="760"/>
        <source>Suggest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="839"/>
        <source>Maximum number of suggestions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="887"/>
        <source>Clear all history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="907"/>
        <source>Clear unused history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1034"/>
        <source>Secret mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1085"/>
        <source>Temporarily disable conversion personalization, history-based suggestions and user dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1164"/>
        <source>Sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1259"/>
        <source>latest sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1288"/>
        <source>Remove all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1355"/>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1402"/>
        <source>Logging level (debug only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1431"/>
        <source>Logging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1463"/>
        <source>Administration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1113"/>
        <location filename="config_dialog.ui" line="1501"/>
        <source>Settings...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1521"/>
        <source>Dictionary preloading and UAC settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1002"/>
        <source>Usage statistics and crash reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="57"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="99"/>
        <source>Punctuation style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="106"/>
        <source>Symbol style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="113"/>
        <source>Space input style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="123"/>
        <source>Selection shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="130"/>
        <source>Numpad style</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="config_dialog.ui" line="147"/>
        <source>character entered by ¥ key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1179"/>
        <source>Synchronization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1217"/>
        <source>Start Sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="287"/>
        <source>Clear personalization data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="383"/>
        <source>Single kanji dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="390"/>
        <source>Symbol dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="397"/>
        <source>Date/time conversion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="404"/>
        <source>Special number conversion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="411"/>
        <source>Emoticon dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="418"/>
        <source>Calculator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="425"/>
        <source>Spelling correction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="432"/>
        <source>Katakana to English dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="439"/>
        <source>Zip code dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="490"/>
        <source>Additional dictionaries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="554"/>
        <source>Special conversions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="576"/>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="665"/>
        <source>Automatically switch to halfwidth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="708"/>
        <source>?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="715"/>
        <source>Convert at punctuations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="741"/>
        <source>!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="751"/>
        <source>Always use Ja keyboard layout for Japanese input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="775"/>
        <source>Source data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="807"/>
        <source>Other settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="874"/>
        <source>Use input history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="894"/>
        <source>Use system dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="940"/>
        <source>Use realtime conversion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="983"/>
        <source>Help make Mozc better by automatically sending usage statistics and crash reports to Google (changes will take effect after you log out and log back in)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1126"/>
        <source>Temporarily disable all suggestions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1142"/>
        <source>Presentation mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1272"/>
        <source>Clear all sync data in Google servers. To delete data completely, make sure there is no other machine which is running sync and stop sync on this machine after clearing the data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1301"/>
        <source>Mozc can securely syncs your settings and a user sync-dictionary among different machines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1317"/>
        <source>Allow Using Cloud Handwriting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1333"/>
        <source>Cloud servers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1546"/>
        <source>Check if Mozc is the default IME on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1370"/>
        <source>Default IME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1556"/>
        <source>Disable Keyboard layout hotkey (Ctrl+Shift)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1595"/>
        <source>Reset to defaults</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GenericTableEditorDialog</name>
    <message>
        <location filename="generic_table_editor.ui" line="14"/>
        <source>Mozc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.ui" line="62"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeyBindingEditor</name>
    <message>
        <location filename="keybinding_editor.ui" line="32"/>
        <source>Mozc key binding editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keybinding_editor.ui" line="92"/>
        <source>Input key assignments:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="character_form_editor.cc" line="16"/>
        <location filename="character_form_editor.cc" line="31"/>
        <source>Fullwidth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="19"/>
        <location filename="character_form_editor.cc" line="33"/>
        <source>Halfwidth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="22"/>
        <location filename="character_form_editor.cc" line="35"/>
        <source>Remember</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="25"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="44"/>
        <location filename="character_form_editor.cc" line="54"/>
        <location filename="character_form_editor.cc" line="124"/>
        <source>Katakana</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="46"/>
        <location filename="character_form_editor.cc" line="57"/>
        <source>Numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="48"/>
        <location filename="character_form_editor.cc" line="59"/>
        <source>Alphabets</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SyncCustomizeDialog</name>
    <message>
        <location filename="sync_customize_dialog.ui" line="26"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="sync_customize_dialog.ui" line="54"/>
        <source>Sync everything</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="sync_customize_dialog.ui" line="70"/>
        <source>config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="sync_customize_dialog.ui" line="77"/>
        <source>user dictionary</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::CharacterFormEditor</name>
    <message>
        <location filename="character_form_editor.cc" line="69"/>
        <source>Fullwidth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="69"/>
        <source>Halfwidth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="69"/>
        <source>Remember</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="73"/>
        <source>Character form editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="91"/>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="91"/>
        <source>Composition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="91"/>
        <source>Conversion</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::ConfigDialog</name>
    <message>
        <location filename="config_dialog.cc" line="94"/>
        <source>Custom keymap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="95"/>
        <location filename="config_dialog.cc" line="99"/>
        <source>ATOK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="96"/>
        <location filename="config_dialog.cc" line="100"/>
        <source>MS-IME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="97"/>
        <location filename="config_dialog.cc" line="101"/>
        <source>Kotoeri</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="103"/>
        <source>Romaji</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="104"/>
        <source>Kana</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="108"/>
        <source>Romaji (switchable)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="109"/>
        <source>Kana (switchable)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="112"/>
        <location filename="config_dialog.cc" line="128"/>
        <source>Follow input mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="113"/>
        <location filename="config_dialog.cc" line="129"/>
        <source>Fullwidth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="114"/>
        <location filename="config_dialog.cc" line="130"/>
        <source>Halfwidth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="116"/>
        <source>No shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="117"/>
        <source>1 -- 9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="118"/>
        <source>A -- L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="120"/>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="121"/>
        <source>Yes (don&apos;t record new data)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="122"/>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="124"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="125"/>
        <source>Alphanumeric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="126"/>
        <source>Katakana</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="131"/>
        <source>Direct input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="133"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="134"/>
        <source>1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="135"/>
        <source>2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="137"/>
        <source>Yen Sign Â¥</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="138"/>
        <source>Backslash \</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="250"/>
        <source>Dictionary preloading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="345"/>
        <location filename="config_dialog.cc" line="365"/>
        <location filename="config_dialog.cc" line="379"/>
        <location filename="config_dialog.cc" line="387"/>
        <location filename="config_dialog.cc" line="675"/>
        <location filename="config_dialog.cc" line="689"/>
        <location filename="config_dialog.cc" line="699"/>
        <location filename="config_dialog.cc" line="711"/>
        <location filename="config_dialog.cc" line="721"/>
        <location filename="config_dialog.cc" line="733"/>
        <location filename="config_dialog.cc" line="806"/>
        <source>Mozc settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="346"/>
        <source>Failed to get current config values</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="366"/>
        <source>The current custom keymap table is empty. When custom keymap is selected, you must customize it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="380"/>
        <source>Romaji/Kana setting is enabled from new applications.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="388"/>
        <source>Failed to update config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="550"/>
        <source>Checking sync status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="552"/>
        <location filename="config_dialog.cc" line="985"/>
        <source>Sync is not enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="676"/>
        <source>Do you want to clear personalization data? Input history is not reset with this operation. Please open &quot;suggestion&quot; tab to remove input history data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="690"/>
        <location filename="config_dialog.cc" line="712"/>
        <source>Mozc Converter is not running. Settings were not saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="700"/>
        <source>Do you want to clear all history data?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="722"/>
        <source>Do you want to clear unused history data?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="734"/>
        <source>Mozc Converter is not running. Operation was not executed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="807"/>
        <source>When you reset Mozc settings, any changes you&apos;ve made will be reverted to the default settings. Do you want to reset settings? The following items are not reset with this operation.
 - Personalization data
 - Input history
 - Sync settings
 - Usage statistics and crash reports
 - Administrator settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="835"/>
        <source>Stop Sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="837"/>
        <source>Start Sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="853"/>
        <source>Stop sync and reset the auth token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="854"/>
        <source>You are trying to stop sync and reset the auth token. To restart sync, you will need to get a new auth token.
Do you really want to continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="938"/>
        <source>Not synced yet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="942"/>
        <source>Last synced time: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="982"/>
        <source>During synchronization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1000"/>
        <source>Authorization failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1003"/>
        <source>Cannot save dictionaries because Sync Dictionary exceeds its entry size limit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1007"/>
        <source>Cannot save dictionaries because Sync Dictionary exceeds its binary size limit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1011"/>
        <source>Cannot save dictionaries because the number of dictionaries for sync exceeds its limit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1015"/>
        <source>Unknown error was found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1028"/>
        <source>Authorization error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1033"/>
        <source>Dictionary sync error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1036"/>
        <source>Unknown sync error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1048"/>
        <source>Clear all sync data in Google servers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1049"/>
        <source>You are trying to clear all the data in the sync server.
Do you really want to continue?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::GenericTableEditorDialog</name>
    <message>
        <location filename="generic_table_editor.cc" line="60"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="132"/>
        <location filename="generic_table_editor.cc" line="177"/>
        <location filename="generic_table_editor.cc" line="188"/>
        <location filename="generic_table_editor.cc" line="210"/>
        <location filename="generic_table_editor.cc" line="218"/>
        <location filename="generic_table_editor.cc" line="226"/>
        <location filename="generic_table_editor.cc" line="248"/>
        <source>Mozc settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="133"/>
        <location filename="generic_table_editor.cc" line="178"/>
        <source>No entry is selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="189"/>
        <source>You can&apos;t have more than %1 entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="201"/>
        <source>import from file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="211"/>
        <source>File not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="219"/>
        <source>The specified file is too large (&gt;=100K byte)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="227"/>
        <source>Import failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="238"/>
        <source>export to file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="249"/>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="282"/>
        <source>New entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="283"/>
        <source>Remove entry</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::KeyMapEditorDialog</name>
    <message>
        <location filename="keymap_editor.cc" line="220"/>
        <source>New entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="222"/>
        <source>Remove selected entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="226"/>
        <source>Import predefined mapping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="230"/>
        <source>ATOK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="231"/>
        <source>MS-IME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="232"/>
        <source>Kotoeri</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="236"/>
        <source>Import from file...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="238"/>
        <source>Export to file...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="280"/>
        <source>Mozc keymap editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="284"/>
        <source>Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="284"/>
        <source>Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="284"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="368"/>
        <location filename="keymap_editor.cc" line="408"/>
        <location filename="keymap_editor.cc" line="427"/>
        <location filename="keymap_editor.cc" line="463"/>
        <source>Mozc settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="369"/>
        <source>Current keymap table is empty. You might want to import a pre-defined keymap table first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="409"/>
        <source>Invalid key:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="428"/>
        <source>The keymaps for IME ON and Reconversion will be applied after new applications.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="464"/>
        <source>Do you want to overwrite the current keymaps?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::RomanTableEditorDialog</name>
    <message>
        <location filename="roman_table_editor.cc" line="32"/>
        <source>New entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="34"/>
        <source>Remove selected entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="37"/>
        <source>Import from file...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="39"/>
        <source>Export to file...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="42"/>
        <source>Reset to defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="44"/>
        <source>Mozc Romaji table editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="48"/>
        <source>Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="48"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="48"/>
        <source>Next input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="127"/>
        <location filename="roman_table_editor.cc" line="149"/>
        <location filename="roman_table_editor.cc" line="189"/>
        <location filename="roman_table_editor.cc" line="216"/>
        <source>Mozc settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="128"/>
        <source>You can&apos;t have more than %1 entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="150"/>
        <source>Romaji to Kana table is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="190"/>
        <source>Input fields contain capital characters. &quot;Shift-mode-switch&quot; function is disabled with this new mapping.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="217"/>
        <source>Do you want to overwrite the current roman table?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::WebServiceInfolistEditorDialog</name>
    <message>
        <location filename="webservice_infolist_editor.cc" line="99"/>
        <source>New entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="101"/>
        <source>Remove selected entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="104"/>
        <source>Import from file...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="106"/>
        <source>Export to file...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="109"/>
        <source>Help...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="111"/>
        <source>Mozc Web Service Usage Dictionary table editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="123"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="123"/>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="124"/>
        <source>Format type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="124"/>
        <source>Xpath/Jsonpath</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="188"/>
        <source>Enter name of Web service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="189"/>
        <source>Enter URL for of Web service.
&quot;%s&quot; is expanded to the candidate string.
&quot;%r&quot; is expanded to the all preedit string.

Example:   http://api.example.com/keyword/%s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="193"/>
        <source>Select format type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="194"/>
        <source>Enter Xpath or Jsonpath.
This query is used for extracting the content from URL.

Example of Xpath:   //content/node
Example of Jsonpath:   $.content.node</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="231"/>
        <source>Mozc settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="232"/>
        <source>You can&apos;t have more than %1 entries</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
